@@ -22,3 +22,6 @@ rm -Rf autom4te.cache
 
 # Remove rest of the generated files.
 rm -f Makefile.in aclocal.m4 configure depcomp install-sh missing
+
+rm -f *~
+rm -f build-stamp
