@@ -69,12 +69,5 @@
 #define TYPE_SELECT "select"
 #define TYPE_ARRAY "array"
 
-int parser_profile(xmlDocPtr doc, char *json, char* remixmid, gboolean image, struct ProfileData *cp);
-int parser_profile_albums(xmlDocPtr doc, char* json, char* remixmid, struct ProfileData *cp);
-int parser_image(xmlDocPtr doc, char* data, char* url);
-int parser_friends(char* json, xmlDocPtr doc, int counter);
-int parser_messages(char *json, xmlDocPtr doc, gchar *message_id, int counter, int max_count);
-int parser_new_messages(char* json);
-int parser_photos(char *json, xmlDocPtr doc, int counter);
-int check(char* json);	
+int parse_upload(char* json, gchar **response);
 #endif
