@@ -35,28 +35,32 @@ struct ProfileData *profile_create(gchar *name)
 {
     struct ProfileData *ret = (struct ProfileData *)malloc(sizeof (struct ProfileData));
     int num_accounts = 0; /* number of exist accounts */
-
+    int id_busy = 0;
+ 
     if (profile_list == NULL) {
-	profile_list = ret;
+    	profile_list = ret;
     } else {
-	struct ProfileData *last = (struct ProfileData *)profile_list;
-	while(last->next != NULL)
-	{
-	    num_accounts++;
-	    last = last->next;
-	}
-	last->next = ret;
+        struct ProfileData *last = (struct ProfileData *)profile_list;
+        while(last->next != NULL) {
+            if(g_strcmp0(last->id, name) == 0) {
+                id_busy = 1;
+            }
+            num_accounts++;
+            last = last->next;
+        }
+        last->next = ret;
     }
     
-    ret->id = g_strdup_printf("%s%d", name, num_accounts);
+    if(id_busy)
+        ret->id = g_strdup_printf("%s%d", name, num_accounts);
+    else
+        ret->id = g_strdup_printf("%s", name);
+
     ret->login = NULL;
     ret->password = NULL;
     ret->remixmid = NULL;
     ret->remixsid = NULL;
-    ret->hash = NULL;
-    ret->rhash = NULL;
-    ret->aid = NULL;
-    ret->upload_url = NULL;
+    ret->secret = NULL;
     ret->next = NULL;
 
     return ret;
@@ -79,6 +83,10 @@ void profile_remove(struct ProfileData *data)
 	g_free(data->remixmid);
     if (data->remixsid != NULL)
 	g_free(data->remixsid);
+    if (data->secret != NULL)
+	g_free(data->secret);
+
+
     free(data);
 }
 
@@ -93,7 +101,7 @@ const struct ProfileData *profile_get_by_id(gchar *id)
     const struct ProfileData *ret = profile_list;
     while(ret != NULL)
     {
-	g_debug("%s:%d:%s: cur_id=%s, list_id=%s", __FILE__, __LINE__, __FUNCTION__, id, ret->id);
+	msa_debug("%s:%d:%s: cur_id=%s, list_id=%s", __FILE__, __LINE__, __FUNCTION__, id, ret->id);
 	if (!strcmp(ret->id, id))
 	    return ret;
         ret = ret->next;
