@@ -24,6 +24,14 @@
 
 #include <glib.h>
 
+#ifdef DEBUG
+#define msa_debug(...) g_debug(__VA_ARGS__)
+#define msa_warning(...) g_warning(__VA_ARGS__)
+#else
+#define msa_debug(...)
+#define msa_warning(...)
+#endif
+
 /*
  * Struct contains all required data for profile. Data load from program and store during work time.
  */
@@ -33,10 +41,7 @@ struct ProfileData {
     gchar *password;
     gchar *remixmid;
     gchar *remixsid;
-    gchar *hash;
-    gchar *rhash;
-    gchar *aid;
-    gchar *upload_url;
+    gchar *secret;
     struct ProfileData *next;
 };
 
